@@ -199,9 +199,13 @@ meteo_imgw_daily <- function(rank, year, status = FALSE, coords = FALSE, station
     }
   }
   
-  
-  all_data <- all_data[order(all_data$`Nazwa stacji.x`, all_data$Rok, all_data$Miesiac, all_data$Dzien),]
-  #powyzsza linia wykrzacza pobieranie
+  # sortowanie w zaleznosci od nazw kolumn - raz jest "kod stacji", raz "id"
+  if(sum(grepl(x = colnames(all_data), pattern = "Kod stacji"))){
+    all_data <- all_data[order(all_data$`Kod stacji`, all_data$Rok, all_data$Miesiac, all_data$Dzien), ]
+  } else {
+    all_data <- all_data[order(all_data$id, all_data$Rok, all_data$Miesiac, all_data$Dzien), ]
+  }
+
   
   
   # # dodanie opcji  dla skracania kolumn i usuwania duplikatow:
