@@ -145,7 +145,14 @@ meteo_imgw_hourly <- function(rank, year, status = FALSE, coords = FALSE, statio
     }
   }
   
-  all_data <- all_data[order(all_data$`Nazwa stacji`, all_data$`Rok`, all_data$`Miesiac`, all_data$`Dzien`, all_data$`Godzina`), ]
+  
+  # sortowanie w zaleznosci od nazw kolumn - raz jest "kod stacji", raz "id"
+  if(sum(grepl(x = colnames(all_data), pattern = "Kod stacji"))){
+    all_data <- all_data[order(all_data$`Kod stacji`, all_data$Rok, all_data$Miesiac, all_data$Dzien, all_data$Godzina), ]
+  } else {
+    all_data <- all_data[order(all_data$id, all_data$Rok, all_data$Miesiac, all_data$Dzien, all_data$Godzina), ]
+  }
+  
   # dodanie opcji  dla skracania kolumn i usuwania duplikatow:
   all_data <- meteo_shortening_imgw(all_data, col_names = col_names, ...)
   return(all_data)
